/*
	block_leave.js contains functionality to prevent the user from leaving the page prematurely.
	Author: Daniel Brand (daniel.brand@metech.tu-chemnitz.de)
*/

// Variable for controling if the page can be left
// If false, a warning "should" (depending on browser settings) be shown
var leavePageAllowed = false;

// Use this function to change the current URL/page
// e.g., changePage("http://www.google.de");
function changePage(targetLocation) {
	leavePageAllowed = true;
	window.location.replace(targetLocation);
}

// The following code tries to prevent the back-button from working
// However, it is not planned by the browser that this works reliably
window.history.pushState(null, document.title, location.href);
window.addEventListener('popstate', function (event)
{
  window.history.pushState(null, document.title, location.href);
});

// Try to prevent user from leaving the page by showing a warning
// The text is usually ignored and replaced by a browser standard
window.addEventListener('beforeunload', (event) => {
	if(!leavePageAllowed) {
		event.preventDefault();
		event.returnValue = 'Please do not leave the page';
		return false;
	}
});
